@@ -59,7 +59,7 @@ impl<'src, D> Recipe<'src, D> {
 
   pub(crate) fn module_path(&self) -> String {
     let mut path = self.namepath.to_string();
-    path.truncate(path.find("::").unwrap_or_default());
+    path.truncate(path.rfind("::").unwrap_or_default());
     path
   }
 
