@@ -32,3 +32,22 @@ fn aliases_in_submodules_run_with_submodule_scope() {
     .stderr("echo X X\n")
     .run();
 }
+
+#[test]
+fn dependencies_in_nested_submodules_run_with_submodule_scope() {
+  Test::new()
+    .write(
+      "b.just",
+      "
+x := 'y'
+
+foo:
+    @echo {{ x }}
+",
+    )
+    .write("a.just", "mod b")
+    .stdout("y\n")
+    .justfile("mod a")
+    .args(["a", "b", "foo"])
+    .run();
+}
